@@ -9,6 +9,7 @@
 
 """Console script for raytraverse."""
 import os
+import re
 import sys
 
 import numpy as np
@@ -16,10 +17,10 @@ import numpy as np
 from clasp import click
 import clasp.click_ext as clk
 import raytraverse
-from raytraverse.integrator import Integrator
-from raytraverse.sampler import SCBinSampler, SunSampler
+from raytraverse.integrator import SunSkyIntegrator, MetricSet, Integrator, BaseIntegrator
+from raytraverse.sampler import SCBinSampler, SunSampler, SkySampler
 from raytraverse.scene import Scene, SunSetter, SunSetterLoc, SunSetterPositions
-from raytraverse.lightfield import SCBinField, SunField, SunViewField
+from raytraverse.lightfield import SCBinField, SunField, SunViewField, StaticField
 
 
 @clk.pretty_name("NPY, TSV, FLOATS,FLOATS")
@@ -379,6 +380,63 @@ def sunrun(ctx, plotdview=False, run=True, rmraw=False, overwrite=False,
                 su.direct_view(items=items)
 
 
+@main.command()
+@click.argument('skydef')
+@clk.shared_decs(run_opts)
+@click.option('-skyname',
+              help='basename for result files')
+@click.option('-fdres', default=10,
+              help='the final directional sampling resolution, yielding a'
+                   ' grid of potential samples at 2^fdres x 2^fdres per'
+                   ' hemisphere')
+@click.option('-accuracy', default=6.0,
+              help='final sampling level will set # of samples by the number of'
+                   ' samples with variance greater than 1/4 this number, which '
+                   'has units of radiance for bright sky conditions this should'
+                   ' be set to a correspondingly higher value (default is 6.0)')
+@click.option('-rcopts',
+              default='-ab 6 -ad 3000 -as 1500 -st 0 -ss 16 -aa .1',
+              help='rtrace options for sun reflection runs'
+                   ' see the man pages for rtrace, and '
+                   ' rtrace -defaults for more information')
+@click.option('--ambcache/--no-ambcache', default=True,
+              help='whether the rcopts indicate that the calculation will use '
+                   'ambient caching (and thus should write an -af file argument'
+                   ' to the engine)')
+@click.option('--keepamb/--no-keepamb', default=False,
+              help='whether to keep ambient files after run, if kept, a '
+                   'successive call will load these ambient files, so care '
+                   'must be taken to not change any parameters')
+@clk.shared_decs(clk.command_decs(raytraverse.__version__, wrap=True))
+def onesky(ctx, skydef, skyname=None, plotdview=False, run=True, rmraw=False,
+           overwrite=False, rebuild=False, **kwargs):
+    """the onesky command is for running one off sky definitions."""
+    if 'scene' not in ctx.obj:
+        clk.invoke_dependency(ctx, scene)
+    scn = ctx.obj['scene']
+    if skyname is None:
+        skyname = re.split(r"[/.]", skydef)[-2]
+    sampler = SkySampler(scn, skydef, skyname, **kwargs)
+    lumf = f'{scn.outdir}/{skyname}_kd_lum.dat'
+    exists = os.path.isfile(lumf) and os.stat(lumf).st_size > 1000
+    rrun = run and (overwrite or not exists)
+    if rrun:
+        sampler.run()
+    try:
+        su = StaticField(scn, sampler.sources, prefix=skyname,
+                         rebuild=rrun or rebuild, rmraw=rmraw)
+    except FileNotFoundError as ex:
+        print(f'Warning: {ex}', file=sys.stderr)
+    else:
+        if plotdview:
+            items = list(su.items())
+            if len(items) >= 20:
+                items = None
+            su.direct_view(items=items)
+            if su.view is not None:
+                su.view.direct_view()
+
+
 @main.command()
 @click.option('-loc', callback=clk.split_float,
               help='specify the scene location (if not specified in -wea or to'
@@ -414,6 +472,8 @@ def sunrun(ctx, plotdview=False, run=True, rmraw=False, overwrite=False,
                    'not apply to metric calculations')
 @click.option('-vname', default='view',
               help='name to include with hdr outputs')
+@click.option('-static',
+              help='name of static field to integrate (overrides other opts)')
 @click.option('-skyro', default=0.0,
               help='counter clockwise rotation (in degrees) of the sky to'
                    ' rotate true North to project North, so if project North'
@@ -423,11 +483,28 @@ def sunrun(ctx, plotdview=False, run=True, rmraw=False, overwrite=False,
 @click.option('--skyonly/--no-skyonly', default=False,
               help="if True, only integrate on Sky Field, useful for "
                    "diagnostics")
+@click.option('--sunonly/--no-sunonly', default=False,
+              help="if True, only integrate on Sun Field, useful for "
+                   "diagnostics. Note: only runs if --skyonly is False")
 @click.option('--hdr/--no-hdr', default=True,
               help="produce an hdr output for each point and line in wea")
 @click.option('--metric/--no-metric', default=True,
               help="calculate metrics for each point and wea file output"
                    " is ordered by point than sky")
+@click.option('-metricset', default="illum avglum lum2 dgp ugr",
+              callback=clk.split_str,
+              help='which metrics to return items must be in: '
+                   f'{", ".join(MetricSet.allmetrics)}')
+@click.option('-threshold', default=2000.0,
+              help='Threshold factor; if factor is larger than 100, it is used '
+                   'as constant threshold in cd/m2. If factor is less or equal '
+                   'than 100,  this  factor  multiplied  by the average task '
+                   'luminance will be used as  threshold for detecting the '
+                   'glare sources. task luminance is taken from the center'
+                   'of the view and encompasses tradius (see parameter '
+                   '-tradius)')
+@click.option('-tradius', default=30.0,
+              help='task radius in degrees for calculating task luminance')
 @click.option('--header/--no-header', default=False,
               help='print column headings on metric output')
 @click.option('--statidx/--no-statidx', default=False,
@@ -441,34 +518,43 @@ def sunrun(ctx, plotdview=False, run=True, rmraw=False, overwrite=False,
               help='print sky info (sun x,y,z dirnorm, dirdiff) on metric '
                    'output')
 @clk.shared_decs(clk.command_decs(raytraverse.__version__, wrap=True))
-def integrate(ctx, pts=None, skyonly=False, hdr=True,
-              metric=True, res=800, interp=12, vname='view',
-              header=False, **kwargs):
+def integrate(ctx, loc=None, wea=None, skyro=0.0, ground_fac=0.15, pts=None,
+              skyonly=False, sunonly=False, hdr=True, metric=True, res=800, interp=12,
+              vname='view', static=None, header=False, metricset="",
+              tradius=30.0, **kwargs):
     """the integrate command combines sky and sun results and evaluates the
     given set of positions and sky conditions"""
     if 'scene' not in ctx.obj:
         clk.invoke_dependency(ctx, scene)
     scn = ctx.obj['scene']
-    if not skyonly:
+
+    if static is not None:
+        sk = StaticField(scn, prefix=static)
+        itg = BaseIntegrator(sk)
+    elif skyonly:
+        sk = SCBinField(scn)
+        itg = Integrator(sk, wea=wea, loc=loc, skyro=skyro,
+                         ground_fac=ground_fac)
+    else:
         if 'suns' not in ctx.obj:
             clk.invoke_dependency(ctx, suns)
         sns = ctx.obj['suns']
         su = SunField(scn, sns)
-    else:
-        su = None
-    sk = SCBinField(scn)
-    itg = Integrator(sk, su, **kwargs)
-    skymtx = itg.get_sky_mtx()
+        if sunonly:
+            itg = Integrator(su, wea=wea, loc=loc, skyro=skyro,
+                             ground_fac=ground_fac)
+        else:
+            sk = SCBinField(scn)
+            itg = SunSkyIntegrator(sk, su, wea=wea, loc=loc, skyro=skyro,
+                                   ground_fac=ground_fac)
     metric_return_opts = {"idx": kwargs['statidx'],
                           "sensor": kwargs['statsensor'],
                           "err": kwargs['staterr'], "sky": kwargs['statsky']}
-    mf = (raytraverse.metricfuncs.illum, raytraverse.metricfuncs.sqlum)
-    datahd, data = itg.integrate(pts, *skymtx, interp=interp, res=res,
-                                 vname=vname, scale=179, mfuncs=mf,
-                                 dohdr=hdr, dometric=metric,
-                                 metric_return_opts=metric_return_opts)
-    if header:
-        print("\t".join(datahd))
+    data = itg.integrate(pts, interp=interp, res=res, vname=vname, scale=179,
+                         metricset=metricset, dohdr=hdr, dometric=metric,
+                         tradius=tradius, metric_return_opts=metric_return_opts)
+    if header and data.size > 0:
+        print("\t".join(itg.metricheader))
     for d in data:
         print("\t".join([f"{i}" for i in d]))
 
