@@ -8,7 +8,11 @@
 
 """mapper objects"""
 
-__all__ = ['Integrator']
+__all__ = ['BaseIntegrator', 'Integrator', 'SunSkyIntegrator',
+           'MetricSet', 'PositionIndex']
 
+from raytraverse.integrator.baseintegrator import BaseIntegrator
 from raytraverse.integrator.integrator import Integrator
-
+from raytraverse.integrator.sunskyintegrator import SunSkyIntegrator
+from raytraverse.integrator.metricset import MetricSet
+from raytraverse.integrator.positionindex import PositionIndex
