@@ -9,7 +9,7 @@
 """light field storage/query objects"""
 
 __all__ = ['LightField', 'LightFieldKD', 'SunViewField', 'SCBinField',
-           'SunField', 'SunSkyPt']
+           'SunField', 'SunSkyPt', 'StaticField']
 
 
 from raytraverse.lightfield.lightfield import LightField
@@ -18,3 +18,4 @@ from raytraverse.lightfield.sunviewfield import SunViewField
 from raytraverse.lightfield.scbinfield import SCBinField
 from raytraverse.lightfield.sunfield import SunField
 from raytraverse.lightfield.sunskypt import SunSkyPt
+from raytraverse.lightfield.staticfield import StaticField
