@@ -5,6 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 # =======================================================================
+import functools
 import os
 import numpy as np
 
@@ -22,7 +23,9 @@ class LightField(object):
         prefix of data files to map
     """
 
-    def __init__(self, scene, rebuild=False, prefix='sky', srcn=1, rmraw=False):
+    def __init__(self, scene, rebuild=False, prefix='sky', srcn=1, rmraw=False,
+                 fvrays=0):
+        self._fvrays = fvrays
         #: bool: force rebuild kd-tree
         self.rebuild = rebuild
         self.srcn = srcn
@@ -71,4 +74,8 @@ class LightField(object):
     def items(self):
         return range(self.scene.area.npts)
 
-
+    @functools.lru_cache(1)
+    def size(self):
+        lfang = len(list(self.omega.keys())) * 4 * np.pi
+        lfcnt = np.sum([v.size for v in self.omega.values()])
+        return dict(lfcnt=lfcnt, lfang=lfang)
