@@ -56,12 +56,13 @@ class SunViewField(LightField):
         # maybe mathematically impossible?
         cnt[ocnt < -redist] += smdg/np.sum(ocnt < -redist)
 
-    def __init__(self, scene, suns, rebuild=False, rmraw=False):
+    def __init__(self, scene, suns, rebuild=False, rmraw=False,
+                 prefix='sunview'):
         #: raytraverse.sunsetter.SunSetter
         self.suns = suns
         #: raytraverse.sunmapper.SunMapper
         self.sunmap = suns.map
-        super().__init__(scene, rebuild=rebuild, prefix='sunview', rmraw=rmraw)
+        super().__init__(scene, rebuild=rebuild, prefix=prefix, rmraw=rmraw)
 
     def raw_files(self):
         """get list of files used to build field"""
@@ -182,9 +183,9 @@ class SunViewField(LightField):
             for p, cl in zip(px, clum):
                 img[tuple(p)] += cl
 
-    def get_ray(self, psi, v, s):
+    def get_ray(self, psi, vm, s):
         sun = np.asarray(s[0:3]).reshape(1, 3)
-        if v.in_view(sun, indices=False)[0] and psi in self.items():
+        if vm.in_view(sun, indices=False)[0] and psi in self.items():
             svlm = self.lum[psi]*s[3]
             svo = self.omega[psi]
             return s[0:3], svlm, svo
