@@ -9,11 +9,11 @@
 """sampler objects"""
 
 __all__ = ['Sampler', 'SCBinSampler', 'SunViewSampler',
-           'SunSampler', 'SingleSunSampler']
+           'SunSampler', 'SingleSunSampler', 'SkySampler']
 
 from raytraverse.sampler.sampler import Sampler
 from raytraverse.sampler.scbinsampler import SCBinSampler
 from raytraverse.sampler.singlesunsampler import SingleSunSampler
 from raytraverse.sampler.sunviewsampler import SunViewSampler
 from raytraverse.sampler.sunsampler import SunSampler
-
+from raytraverse.sampler.skysampler import SkySampler
